# convert unix to dos line endings

""" Convert unix -> dos text replacing line endings.

Usage:  u2d file [ file ... ]

NOTE: 
1) This program replaces files IN-PLACE. This 
makes it very dangerous if the process is 
interrupted -- a file can be truncated. 
2) This program checks if the file has already been
converted. If so, it does not do it again.
3) If one or more files can not be read, an error
message is issued and the rest of the files in the 
list are converted.

This utility is meant to be used on a list of
files, as is found in a directory. So you can
use this tool to convert some or all files in 
a directory.
"""

import sys, os

class ProcessFile( object ):
  def __init__( self, fn ):
    """ Open file and read all its lines 
    into a cache which will be used later.
    """
    self.inlines = []
    if ( os.path.isfile( fn ) 
    and os.access( fn, os.R_OK | os.W_OK ) ):
      try:
        # read in all the input file
        f = open( fn )
        self.inlines = f.readlines()
        f.close()
      except IOError, e:
        sys.stderr.write("Can't convert %s\n" % fn)
    else:
      sys.stderr.write("Can't find file %s\n" % fn)
          
  def needsConverting( self ):
    """ Check if any lines need converting. 
    
    A file needs converting if every line ends 
    in '\r\n' else it is already in the right 
    format. This check prevents converting an 
    already converted file.
    """
    for inl in self.inlines:
      if inl[-2:] != '\r\n':
        return True
    return False
    
def usage():
  """ Print usage for this tool."""
  print sys.modules['__main__'].__doc__

def mymain( args ):
  """ 
  Loop thru each file in the command line list, 
  trying to convert each file in turn.
  """
  for fn in args:
    pf = ProcessFile( fn )
    if pf.needsConverting():
      print "Converting %s..." % fn,
      of = open( fn, "w" )
      for inl in pf.inlines:
        inl = inl[:-1]+'\r\n'
        of.write( inl )
      of.close()
      print "done"
    else:
      print "Skipping %s - already converted\n" % fn
      
if __name__ == "__main__":
  """ Main routine to invoke tool."""
  if len( sys.argv ) > 1:
    mymain( sys.argv[1:] )
  else:
    usage()
